@@ -34,11 +34,9 @@ bool FLACng::init()
 {
     /* Callback structure and decoder for main decoding loop */
     auto flac_decoder = StreamDecoderPtr(FLAC__stream_decoder_new());
-    auto ogg_flac_decoder = StreamDecoderPtr(FLAC__stream_decoder_new());
-
-    if (!flac_decoder || !ogg_flac_decoder)
+    if (!flac_decoder)
     {
-        AUDERR("Could not create the FLAC decoder instances!\n");
+        AUDERR("Could not create the main FLAC decoder instance!\n");
         return false;
     }
 
@@ -47,20 +45,36 @@ bool FLACng::init()
         eof_callback, write_callback, metadata_callback, error_callback,
         &s_cinfo);
 
-    auto ret2 = FLAC__stream_decoder_init_ogg_stream(ogg_flac_decoder.get(),
-        read_callback, seek_callback, tell_callback, length_callback,
-        eof_callback, write_callback, metadata_callback, error_callback,
-        &s_cinfo);
-
-    if (ret1 != FLAC__STREAM_DECODER_INIT_STATUS_OK ||
-        ret2 != FLAC__STREAM_DECODER_INIT_STATUS_OK)
+    if (ret1 != FLAC__STREAM_DECODER_INIT_STATUS_OK)
     {
-        AUDERR("Could not initialize the FLAC decoders!\n");
+        AUDERR("Could not initialize the main FLAC decoder!\n");
         return false;
     }
 
+    if (FLAC_API_SUPPORTS_OGG_FLAC)
+    {
+        auto ogg_flac_decoder = StreamDecoderPtr(FLAC__stream_decoder_new());
+        if (!ogg_flac_decoder)
+        {
+            AUDERR("Could not create the Ogg FLAC decoder instance!\n");
+            return false;
+        }
+
+        auto ret2 = FLAC__stream_decoder_init_ogg_stream(ogg_flac_decoder.get(),
+            read_callback, seek_callback, tell_callback, length_callback,
+            eof_callback, write_callback, metadata_callback, error_callback,
+            &s_cinfo);
+
+        if (ret2 != FLAC__STREAM_DECODER_INIT_STATUS_OK)
+        {
+            AUDERR("Could not initialize the Ogg FLAC decoder!\n");
+            return false;
+        }
+
+        s_ogg_decoder = std::move(ogg_flac_decoder);
+    }
+
     s_decoder = std::move(flac_decoder);
-    s_ogg_decoder = std::move(ogg_flac_decoder);
 
     return true;
 }
@@ -117,8 +131,16 @@ bool FLACng::play(const char *filename, VFSFile &file)
     Index<char> play_buffer;
     bool error = false;
     bool stream = (file.fsize() < 0);
+    bool _is_ogg_flac = is_ogg_flac(file);
     auto tuple = stream ? get_playback_tuple() : Tuple();
-    auto decoder = is_ogg_flac(file) ? s_ogg_decoder.get() : s_decoder.get();
+    auto decoder = _is_ogg_flac && FLAC_API_SUPPORTS_OGG_FLAC
+                       ? s_ogg_decoder.get() : s_decoder.get();
+
+    if (_is_ogg_flac && !FLAC_API_SUPPORTS_OGG_FLAC)
+    {
+        AUDWARN("Ogg FLAC file detected, but your FLAC library does not support "
+                "this format. Falling back to the main FLAC decoder.\n");
+    }
 
     s_cinfo.fd = &file;
 
