@@ -31,6 +31,7 @@
 #include <libaudcore/plugin.h>
 #include <libaudcore/plugins.h>
 #include <libaudcore/runtime.h>
+#include <libaudgui/gtk-compat.h>
 #include <libaudgui/libaudgui.h>
 #include <libaudgui/libaudgui-gtk.h>
 
@@ -58,6 +59,12 @@ static const char * const gtkui_defaults[] = {
     "playlist_headers", "TRUE",
     "show_remaining_time", "FALSE",
 
+#ifdef USE_GTK3
+    "symbolic_icons", "TRUE",
+#else
+    "symbolic_icons", "FALSE",
+#endif
+
     "player_x", "-1000",
     "player_y", "-1000",
     "player_width", "768",
@@ -126,8 +133,9 @@ static GtkAccelGroup * accel;
 
 static GtkWidget * window, * vbox_outer, * menu_box, * menu, * toolbar, * vbox,
  * infoarea, * statusbar;
-static GtkToolItem * menu_button, * search_button, * button_play, * button_stop,
- * button_record, * button_shuffle, * button_repeat;
+static GtkToolItem * menu_button, * search_button, * button_open, * button_add,
+ * button_prev, * button_play, * button_stop, * button_next, * button_record,
+ * button_repeat, * button_shuffle;
 static GtkWidget * slider, * label_time;
 static GtkWidget * menu_main, * menu_rclick, * menu_tab;
 
@@ -420,10 +428,18 @@ static void update_volume_delta ()
     gtk_adjustment_set_page_increment (adjustment, volume_delta);
 }
 
+static void set_button_icon (GtkToolButton * button, const char * icon)
+{
+    if (aud_get_bool ("gtkui", "symbolic_icons"))
+        gtk_tool_button_set_icon_name (button, str_concat ({icon, "-symbolic"}));
+    else
+        gtk_tool_button_set_icon_name (button, icon);
+}
+
 static void pause_cb ()
 {
     bool paused = aud_drct_get_paused ();
-    gtk_tool_button_set_icon_name ((GtkToolButton *) button_play,
+    set_button_icon ((GtkToolButton *) button_play,
      paused ? "media-playback-start" : "media-playback-pause");
     gtk_tool_item_set_tooltip_text (button_play, paused ? _("Play") : _("Pause"));
 }
@@ -455,7 +471,7 @@ static void ui_playback_stop ()
     timer_remove (TimerRate::Hz4, time_counter_cb);
 
     title_change ();
-    gtk_tool_button_set_icon_name ((GtkToolButton *) button_play, "media-playback-start");
+    set_button_icon ((GtkToolButton *) button_play, "media-playback-start");
     gtk_tool_item_set_tooltip_text (button_play, _("Play"));
     gtk_widget_set_sensitive ((GtkWidget *) button_stop, false);
     gtk_widget_hide (slider);
@@ -466,7 +482,7 @@ static GtkToolItem * toolbar_button_add (GtkWidget * toolbar,
  void (* callback) (), const char * icon, const char * tooltip)
 {
     GtkToolItem * item = gtk_tool_button_new (nullptr, nullptr);
-    gtk_tool_button_set_icon_name ((GtkToolButton *) item, icon);
+    set_button_icon ((GtkToolButton *) item, icon);
     gtk_tool_item_set_tooltip_text (item, tooltip);
     gtk_toolbar_insert ((GtkToolbar *) toolbar, item, -1);
     g_signal_connect (item, "clicked", callback, nullptr);
@@ -477,7 +493,7 @@ static GtkToolItem * toggle_button_new (const char * icon, const char * tooltip,
  void (* toggled) (GtkToggleToolButton *), bool is_toggled)
 {
     GtkToolItem * item = gtk_toggle_tool_button_new ();
-    gtk_tool_button_set_icon_name ((GtkToolButton *) item, icon);
+    set_button_icon ((GtkToolButton *) item, icon);
     gtk_tool_item_set_tooltip_text (item, tooltip);
     gtk_toggle_tool_button_set_active ((GtkToggleToolButton *) item, is_toggled);
     g_signal_connect (item, "toggled", (GCallback) toggled, nullptr);
@@ -601,7 +617,7 @@ static gboolean playlist_keypress_cb (GtkWidget *, GdkEventKey * event)
             pl_remove_selected ();
             return true;
         case GDK_KEY_Menu:
-            popup_menu_rclick (0, event->time);
+            popup_menu_rclick ((const GdkEvent *) event);
             return true;
         }
 
@@ -786,10 +802,10 @@ bool GtkUI::init ()
     accel = gtk_accel_group_new ();
     gtk_window_add_accel_group ((GtkWindow *) window, accel);
 
-    vbox_outer = gtk_vbox_new (false, 0);
+    vbox_outer = audgui_vbox_new (0);
     gtk_container_add ((GtkContainer *) window, vbox_outer);
 
-    menu_box = gtk_hbox_new (false, 0);
+    menu_box = audgui_hbox_new (0);
     gtk_box_pack_start ((GtkBox *) vbox_outer, menu_box, false, false, 0);
 
     toolbar = gtk_toolbar_new ();
@@ -797,6 +813,11 @@ bool GtkUI::init ()
     gtk_toolbar_set_show_arrow ((GtkToolbar *) toolbar, false);
     gtk_box_pack_start ((GtkBox *) vbox_outer, toolbar, false, false, 0);
 
+#ifdef USE_GTK3
+    GtkStyleContext * context = gtk_widget_get_style_context (toolbar);
+    gtk_style_context_add_class (context, GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+#endif
+
     /* search button */
     if (search_tool)
     {
@@ -807,16 +828,16 @@ bool GtkUI::init ()
     }
 
     /* open/add buttons */
-    toolbar_button_add (toolbar, button_open_pressed, "document-open", _("Open Files"));
-    toolbar_button_add (toolbar, button_add_pressed, "list-add", _("Add Files"));
+    button_open = toolbar_button_add (toolbar, button_open_pressed, "document-open", _("Open Files"));
+    button_add = toolbar_button_add (toolbar, button_add_pressed, "list-add", _("Add Files"));
 
     gtk_toolbar_insert ((GtkToolbar *) toolbar, gtk_separator_tool_item_new (), -1);
 
     /* playback buttons */
-    toolbar_button_add (toolbar, aud_drct_pl_prev, "media-skip-backward", _("Previous"));
+    button_prev = toolbar_button_add (toolbar, aud_drct_pl_prev, "media-skip-backward", _("Previous"));
     button_play = toolbar_button_add (toolbar, aud_drct_play_pause, "media-playback-start", _("Play"));
     button_stop = toolbar_button_add (toolbar, aud_drct_stop, "media-playback-stop", _("Stop"));
-    toolbar_button_add (toolbar, aud_drct_pl_next, "media-skip-forward", _("Next"));
+    button_next = toolbar_button_add (toolbar, aud_drct_pl_next, "media-skip-forward", _("Next"));
 
     button_record = toggle_button_new ("media-record", _("Record Stream"),
      toggle_record, aud_get_bool ("record"));
@@ -831,10 +852,10 @@ bool GtkUI::init ()
     gtk_tool_item_set_expand (boxitem1, true);
     gtk_toolbar_insert ((GtkToolbar *) toolbar, boxitem1, -1);
 
-    GtkWidget * box1 = gtk_hbox_new (false, 0);
+    GtkWidget * box1 = audgui_hbox_new (0);
     gtk_container_add ((GtkContainer *) boxitem1, box1);
 
-    slider = gtk_hscale_new (nullptr);
+    slider = audgui_scale_new (GTK_ORIENTATION_HORIZONTAL, nullptr);
     gtk_scale_set_draw_value ((GtkScale *) slider, false);
     gtk_widget_set_size_request (slider, audgui_get_dpi () * 5 / 4, -1);
     gtk_widget_set_can_focus (slider, false);
@@ -862,7 +883,7 @@ bool GtkUI::init ()
     GtkToolItem * boxitem2 = gtk_tool_item_new ();
     gtk_toolbar_insert ((GtkToolbar *) toolbar, boxitem2, -1);
 
-    GtkWidget * box2 = gtk_hbox_new (false, 0);
+    GtkWidget * box2 = audgui_hbox_new (0);
     gtk_container_add ((GtkContainer *) boxitem2, box2);
 
     volume = gtk_volume_button_new ();
@@ -884,7 +905,7 @@ bool GtkUI::init ()
     GtkWidget * layout = layout_new ();
     gtk_box_pack_start ((GtkBox *) vbox_outer, layout, true, true, 0);
 
-    vbox = gtk_vbox_new (false, 6);
+    vbox = audgui_vbox_new (6);
     layout_add_center (vbox);
 
     gtk_box_pack_start ((GtkBox *) vbox, pl_notebook_new (), true, true, 0);
@@ -962,6 +983,7 @@ void GtkUI::cleanup ()
     audgui_cleanup ();
 }
 
+#ifndef USE_GTK3
 static void menu_position_cb (GtkMenu *, int * x, int * y, int * push, void * button)
 {
     GtkAllocation alloc;
@@ -975,14 +997,23 @@ static void menu_position_cb (GtkMenu *, int * x, int * y, int * push, void * bu
     * y = yorig + ywin + alloc.height;
     * push = true;
 }
+#endif
 
 static void menu_button_cb ()
 {
-    if (gtk_toggle_tool_button_get_active ((GtkToggleToolButton *) menu_button))
-        gtk_menu_popup ((GtkMenu *) menu_main, nullptr, nullptr, menu_position_cb,
-         menu_button, 0, gtk_get_current_event_time ());
-    else
+    if (! gtk_toggle_tool_button_get_active ((GtkToggleToolButton *) menu_button))
+    {
         gtk_widget_hide (menu_main);
+        return;
+    }
+
+#ifdef USE_GTK3
+    gtk_menu_popup_at_widget ((GtkMenu *) menu_main, (GtkWidget *) menu_button,
+     GDK_GRAVITY_SOUTH_WEST, GDK_GRAVITY_STATIC, nullptr);
+#else
+    gtk_menu_popup ((GtkMenu *) menu_main, nullptr, nullptr, menu_position_cb,
+     menu_button, 0, gtk_get_current_event_time ());
+#endif
 }
 
 static void menu_hide_cb ()
@@ -1090,16 +1121,26 @@ void show_hide_statusbar ()
     }
 }
 
-void popup_menu_rclick (unsigned button, uint32_t time)
+static void popup_menu (GtkMenu * menu, const GdkEvent * event)
 {
-    gtk_menu_popup ((GtkMenu *) menu_rclick, nullptr, nullptr, nullptr, nullptr, button,
-     time);
+#ifdef USE_GTK3
+    gtk_menu_popup_at_pointer (menu, event);
+#else
+    GdkEventButton * button_event = (GdkEventButton *) event;
+    gtk_menu_popup ((GtkMenu *) menu, nullptr, nullptr, nullptr, nullptr,
+     button_event->button, button_event->time);
+#endif
 }
 
-void popup_menu_tab (unsigned button, uint32_t time, Playlist playlist)
+void popup_menu_rclick (const GdkEvent * event)
+{
+    popup_menu ((GtkMenu *) menu_rclick, event);
+}
+
+void popup_menu_tab (const GdkEvent * event, Playlist playlist)
 {
     menu_tab_playlist = playlist;
-    gtk_menu_popup ((GtkMenu *) menu_tab, nullptr, nullptr, nullptr, nullptr, button, time);
+    popup_menu ((GtkMenu *) menu_tab, event);
 }
 
 void activate_search_tool ()
@@ -1120,3 +1161,18 @@ void activate_playlist_manager ()
     aud_plugin_enable (manager, true);
     layout_focus (manager);
 }
+
+void update_toolbar_icons ()
+{
+    set_button_icon ((GtkToolButton *) search_button, "edit-find");
+    set_button_icon ((GtkToolButton *) button_open, "document-open");
+    set_button_icon ((GtkToolButton *) button_add, "list-add");
+    set_button_icon ((GtkToolButton *) button_prev, "media-skip-backward");
+    set_button_icon ((GtkToolButton *) button_play, aud_drct_get_playing ()
+     ? "media-playback-pause" : "media-playback-start");
+    set_button_icon ((GtkToolButton *) button_stop, "media-playback-stop");
+    set_button_icon ((GtkToolButton *) button_next, "media-skip-forward");
+    set_button_icon ((GtkToolButton *) button_record, "media-record");
+    set_button_icon ((GtkToolButton *) button_repeat, "media-playlist-repeat");
+    set_button_icon ((GtkToolButton *) button_shuffle, "media-playlist-shuffle");
+}
